
import java.io.File


class Game(startLevel:File) {
  
  
  try { // try to open the level file
    initGame(startLevel)
  } catch {
    case e: Exception =>
      e.printStackTrace()
  }
  
  /**
   * Creates a new game grid by reading it from file specified by <code>f</code>. The file should be
   * a text file (.txt).
   * 
   * Structure of the file is:
   * width of the field as positive integer value
   * height of the field as positive integer value
   * field specified with following characters:
   * "@" - for <code>PLAYER</code
   * "#" - for <code>WALL</code>
   * "$" - for <code>OBSTACLE</code>
   * "G" - for <code>GOAL</code>
   * " " - (space) for <code>EMPTY</code>
   * 
   * If the width or height is not positive <code>IllegalArgumentException</code> will be thrown. If
   * either of width or height is not an integer or one of them is missing
   * <code>NumberFormatException</code> will be thrown.
   * 
   * If the field does not contain a player or contains several goals it will not be accepted (and
   * <code>IllegalArgumentException</code> will be thrown).
   * 
   * If the field specification is wider or higher than specified by given values, extra characters
   * will be disregarded.
   * 
   * If the field contains any other characters they are seen as walls.
   * 
   * @param f	a file that contains game's field specification
   */
  private def initGame(f:File) : Unit = {
  
  }
  
  /**
   * Help method that translates <code>String</code>s to <code>GridType</code>s.  
   * 
   * @param s	the <code>String</code> representation of a tile
   * @param x	the x-coordinate of the tile
   * @param y	the y-coordinate of the tile
   * @return	the <code>GridType</code> value represented by the <code>String</code> <code>s</code>
   */
  private def translateToGridType(s:String, x:Int, y:Int) : GridType.Value = {
    GridType.EMPTY
  }
  
  /**
   * Returns the type of the tile in <code>GridType</code> format specified by given coordinates.
   * 
   * @param x	the x-coordinate of needed tile
   * @param y	the y-coordinate of needed tile
   * @return	type of the needed tile as <code>GridType</code> object
   */
  def getGridType(x:Int, y:Int) : GridType.Value = {
    GridType.EMPTY
  }
  
  /**
   * Helping method that tells if the game is ended. Game end when the <code>PLAYER</code reaches
   * the <code>GOAL</code>.
   * 
   * @return	<code>true</code> if the game has finished, otherwise <code>false</code>
   */
  def hasGameFinished() : Boolean = {
    false
  }
  
  
  /**
   * Verifies if moving from players current position to specified position is possible (with one
   * move).
   * 
   * Moving is possible only if the specified tile is <code>EMPTY</code> or if it's an
   * <code>OBSTACLE</code> and the tile behind it is <code>EMPTY</code>.
   * 
   * Moving through <code>WALL</code>s, farther than to the neighboring tile, diagonally or pushing
   * obstacles outside the game area is not permitted. 
   * 
   * @param x	the x-coordinate where player is trying to move
   * @param y	the y-coordinate where player is trying to move
   * @return	<code>true</code> if moving is possible, otherwise <code>false</code>
   */
  private def canMoveTo(x:Int, y:Int) : Boolean = {
    false
  }
  
  /**
   * Moves the player in the specified location (if it is possible). The method takes care that
   * the state of the field (including players moves and possible obstacle moves) and players
   * position is updated.
   * 
   * @param x	the x-coordinate where player is trying to move
   * @param y	the y-coordinate where player is trying to move
   * @return	<code>true</code> if move successful, otherwise <code>false</code>
   */
  def move(x:Int, y:Int) : Boolean = {
    false  
  }
  
  /**
   * Returns the state of the game field to the state that it was in the beginning of the game.
   * The player starts from the initial place and all obstacles are in the original positions.
   */
  def startOver() : Unit = {
    
  }
  
  /**
   * Another version of <code>startOver</code> method that takes a new game field file as an
   * argument. The game is started from the state that the new file specifies.
   * 
   * @param f	the file containing details of the new field
   */
  def startOver(f:File) : Unit = {
    
  }

}

